pyIslam
===========
[![Build Status](https://travis-ci.org/abougouffa/pyIslam.svg?branch=master)](https://travis-ci.org/abougouffa/pyIslam)

**_pyIslam_** is a python islamic library, it will be able (when completed) to calculate **prayer times**, **qibla** direction, convert between gregorian and **hijri**, calculate **zakat** and **mirath**.

Actually, the library can does:

- [x] Pray times calculation
- [x] Hijri/Gregorian date conversion
- [x] Qibla direction
- [x] Zakat calculation **(need checking)**
- [x] Mirath calculation **(need checking)**

# Author
- Abdelhak Bougouffa [@abougouffa](https://github.com/abougouffa)

# Contributors
- Monsef Alahem [@monsef-alahem](https://github.com/monsef-alahem)
- Azzam S. A. [@azzamsa](https://github.com/azzamsa)

------
<div dir='rtl'>
  <b><i>pyIslam</i></b>
هي مكتبة إسلامية للغة البرمجة بايثون، ستكون المكتبة قادرة على (عندما تكتمل) حساب
  <b>أوقات الصلاة</b>،
  اتجاه <b>القبلة</b>، 
  التحويل بين التاريخ الميلادي و<b>الهجري</b>،
  حساب مقادير <b>الزكاة</b>
  وحساب <b>الميراث</b>.
</div>
<div dir='rtl'>
حاليا، المكتبة تستطيع أن تقوم بـ:
</div>

- [x] <span dir='rtl'>حساب مواقيت الصلاة</span>
- [x] <span dir='rtl'>التحويل بين التاريخ الهجري والميلادي</span>
- [x] <span dir='rtl'>تحديد اتجاه القبلة</span>
- [x] <span dir='rtl'>حساب الزكاة</span>
- [x] <span dir='rtl'>حساب الميراث</span>
